"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AggregationAuthorization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTHORIZED_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    AUTHORIZED_AWS_REGION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    authorized_account_id: builtins.str
    authorized_aws_region: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        authorized_account_id: builtins.str = ...,
        authorized_aws_region: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorized_account_id", b"authorized_account_id", "authorized_aws_region", b"authorized_aws_region", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___AggregationAuthorization = AggregationAuthorization

@typing_extensions.final
class Config(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGGREGATION_AUTHORIZATION_FIELD_NUMBER: builtins.int
    CONFIG_RULE_FIELD_NUMBER: builtins.int
    CONFIGURATION_AGGREGATOR_FIELD_NUMBER: builtins.int
    CONFIGURATION_RECORDER_FIELD_NUMBER: builtins.int
    CONFORMANCE_PACK_FIELD_NUMBER: builtins.int
    DELIVERY_CHANNEL_FIELD_NUMBER: builtins.int
    ORGANIZATION_CONFIG_RULE_FIELD_NUMBER: builtins.int
    ORGANIZATION_CONFORMANCE_PACK_FIELD_NUMBER: builtins.int
    REMEDIATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    REMEDIATION_CONFIGURATION_REMEDIATION_PARAMETER_VALUE_FIELD_NUMBER: builtins.int
    @property
    def aggregation_authorization(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AggregationAuthorization]: ...
    @property
    def config_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigRule]: ...
    @property
    def configuration_aggregator(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationAggregator]: ...
    @property
    def configuration_recorder(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationRecorder]: ...
    @property
    def conformance_pack(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConformancePack]: ...
    @property
    def delivery_channel(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryChannel]: ...
    @property
    def organization_config_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OrganizationConfigRule]: ...
    @property
    def organization_conformance_pack(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OrganizationConformancePack]: ...
    @property
    def remediation_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RemediationConfiguration]: ...
    @property
    def remediation_configuration_remediation_parameter_value(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RemediationConfigurationRemediationParameterValue]: ...
    def __init__(
        self,
        *,
        aggregation_authorization: collections.abc.Iterable[global___AggregationAuthorization] | None = ...,
        config_rule: collections.abc.Iterable[global___ConfigRule] | None = ...,
        configuration_aggregator: collections.abc.Iterable[global___ConfigurationAggregator] | None = ...,
        configuration_recorder: collections.abc.Iterable[global___ConfigurationRecorder] | None = ...,
        conformance_pack: collections.abc.Iterable[global___ConformancePack] | None = ...,
        delivery_channel: collections.abc.Iterable[global___DeliveryChannel] | None = ...,
        organization_config_rule: collections.abc.Iterable[global___OrganizationConfigRule] | None = ...,
        organization_conformance_pack: collections.abc.Iterable[global___OrganizationConformancePack] | None = ...,
        remediation_configuration: collections.abc.Iterable[global___RemediationConfiguration] | None = ...,
        remediation_configuration_remediation_parameter_value: collections.abc.Iterable[global___RemediationConfigurationRemediationParameterValue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aggregation_authorization", b"aggregation_authorization", "config_rule", b"config_rule", "configuration_aggregator", b"configuration_aggregator", "configuration_recorder", b"configuration_recorder", "conformance_pack", b"conformance_pack", "delivery_channel", b"delivery_channel", "organization_config_rule", b"organization_config_rule", "organization_conformance_pack", b"organization_conformance_pack", "remediation_configuration", b"remediation_configuration", "remediation_configuration_remediation_parameter_value", b"remediation_configuration_remediation_parameter_value"]) -> None: ...

global___Config = Config

@typing_extensions.final
class ConfigRuleScope(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPLIANCE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    COMPLIANCE_RESOURCE_TYPES_FIELD_NUMBER: builtins.int
    TAG_KEY_FIELD_NUMBER: builtins.int
    TAG_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    compliance_resource_id: builtins.str
    @property
    def compliance_resource_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    tag_key: builtins.str
    tag_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        compliance_resource_id: builtins.str = ...,
        compliance_resource_types: collections.abc.Iterable[builtins.str] | None = ...,
        tag_key: builtins.str = ...,
        tag_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compliance_resource_id", b"compliance_resource_id", "compliance_resource_types", b"compliance_resource_types", "resource_info", b"resource_info", "tag_key", b"tag_key", "tag_value", b"tag_value"]) -> None: ...

global___ConfigRuleScope = ConfigRuleScope

@typing_extensions.final
class ConfigRuleSourceDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EVENT_SOURCE_FIELD_NUMBER: builtins.int
    MAXIMUM_EXECUTION_FREQUENCY_FIELD_NUMBER: builtins.int
    MESSAGE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    event_source: builtins.str
    maximum_execution_frequency: builtins.str
    message_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        event_source: builtins.str = ...,
        maximum_execution_frequency: builtins.str = ...,
        message_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_source", b"event_source", "maximum_execution_frequency", b"maximum_execution_frequency", "message_type", b"message_type", "resource_info", b"resource_info"]) -> None: ...

global___ConfigRuleSourceDetail = ConfigRuleSourceDetail

@typing_extensions.final
class ConfigRuleSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    SOURCE_DETAILS_FIELD_NUMBER: builtins.int
    SOURCE_IDENTIFIER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    owner: builtins.str
    @property
    def source_details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigRuleSourceDetail]: ...
    source_identifier: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        owner: builtins.str = ...,
        source_details: collections.abc.Iterable[global___ConfigRuleSourceDetail] | None = ...,
        source_identifier: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["owner", b"owner", "resource_info", b"resource_info", "source_details", b"source_details", "source_identifier", b"source_identifier"]) -> None: ...

global___ConfigRuleSource = ConfigRuleSource

@typing_extensions.final
class ConfigRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class InputParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONFIG_RULE_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    INPUT_PARAMETERS_FIELD_NUMBER: builtins.int
    MAXIMUM_EXECUTION_FREQUENCY_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    config_rule_name: builtins.str
    description: builtins.str
    @property
    def input_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    maximum_execution_frequency: builtins.str
    @property
    def scope(self) -> global___ConfigRuleScope: ...
    @property
    def source(self) -> global___ConfigRuleSource: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        config_rule_name: builtins.str = ...,
        description: builtins.str = ...,
        input_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        maximum_execution_frequency: builtins.str = ...,
        scope: global___ConfigRuleScope | None = ...,
        source: global___ConfigRuleSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "scope", b"scope", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_rule_name", b"config_rule_name", "description", b"description", "input_parameters", b"input_parameters", "maximum_execution_frequency", b"maximum_execution_frequency", "resource_info", b"resource_info", "scope", b"scope", "source", b"source"]) -> None: ...

global___ConfigRule = ConfigRule

@typing_extensions.final
class ConfigurationAggregatorAccountAggregationSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALL_AWS_REGIONS_FIELD_NUMBER: builtins.int
    AWS_REGIONS_FIELD_NUMBER: builtins.int
    ACCOUNT_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    all_aws_regions: builtins.bool
    @property
    def aws_regions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def account_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        all_aws_regions: builtins.bool = ...,
        aws_regions: collections.abc.Iterable[builtins.str] | None = ...,
        account_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_ids", b"account_ids", "all_aws_regions", b"all_aws_regions", "aws_regions", b"aws_regions", "resource_info", b"resource_info"]) -> None: ...

global___ConfigurationAggregatorAccountAggregationSource = ConfigurationAggregatorAccountAggregationSource

@typing_extensions.final
class ConfigurationAggregatorOrganizationAggregationSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALL_AWS_REGIONS_FIELD_NUMBER: builtins.int
    AWS_REGIONS_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    all_aws_regions: builtins.bool
    @property
    def aws_regions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        all_aws_regions: builtins.bool = ...,
        aws_regions: collections.abc.Iterable[builtins.str] | None = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_aws_regions", b"all_aws_regions", "aws_regions", b"aws_regions", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ConfigurationAggregatorOrganizationAggregationSource = ConfigurationAggregatorOrganizationAggregationSource

@typing_extensions.final
class ConfigurationAggregator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCOUNT_AGGREGATION_SOURCES_FIELD_NUMBER: builtins.int
    CONFIGURATION_AGGREGATOR_NAME_FIELD_NUMBER: builtins.int
    ORGANIZATION_AGGREGATION_SOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def account_aggregation_sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationAggregatorAccountAggregationSource]: ...
    configuration_aggregator_name: builtins.str
    @property
    def organization_aggregation_source(self) -> global___ConfigurationAggregatorOrganizationAggregationSource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        account_aggregation_sources: collections.abc.Iterable[global___ConfigurationAggregatorAccountAggregationSource] | None = ...,
        configuration_aggregator_name: builtins.str = ...,
        organization_aggregation_source: global___ConfigurationAggregatorOrganizationAggregationSource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["organization_aggregation_source", b"organization_aggregation_source", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_aggregation_sources", b"account_aggregation_sources", "configuration_aggregator_name", b"configuration_aggregator_name", "organization_aggregation_source", b"organization_aggregation_source", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___ConfigurationAggregator = ConfigurationAggregator

@typing_extensions.final
class ConfigurationRecorderRecordingGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALL_SUPPORTED_FIELD_NUMBER: builtins.int
    INCLUDE_GLOBAL_RESOURCE_TYPES_FIELD_NUMBER: builtins.int
    RESOURCE_TYPES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    all_supported: builtins.bool
    include_global_resource_types: builtins.bool
    @property
    def resource_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        all_supported: builtins.bool = ...,
        include_global_resource_types: builtins.bool = ...,
        resource_types: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_supported", b"all_supported", "include_global_resource_types", b"include_global_resource_types", "resource_info", b"resource_info", "resource_types", b"resource_types"]) -> None: ...

global___ConfigurationRecorderRecordingGroup = ConfigurationRecorderRecordingGroup

@typing_extensions.final
class ConfigurationRecorder(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RECORDING_GROUP_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def recording_group(self) -> global___ConfigurationRecorderRecordingGroup: ...
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        recording_group: global___ConfigurationRecorderRecordingGroup | None = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["recording_group", b"recording_group", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "recording_group", b"recording_group", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ConfigurationRecorder = ConfigurationRecorder

@typing_extensions.final
class ConformancePackConformancePackInputParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARAMETER_NAME_FIELD_NUMBER: builtins.int
    PARAMETER_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    parameter_name: builtins.str
    parameter_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        parameter_name: builtins.str = ...,
        parameter_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameter_name", b"parameter_name", "parameter_value", b"parameter_value", "resource_info", b"resource_info"]) -> None: ...

global___ConformancePackConformancePackInputParameter = ConformancePackConformancePackInputParameter

@typing_extensions.final
class ConformancePack(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONFORMANCE_PACK_NAME_FIELD_NUMBER: builtins.int
    DELIVERY_S3_BUCKET_FIELD_NUMBER: builtins.int
    DELIVERY_S3_KEY_PREFIX_FIELD_NUMBER: builtins.int
    TEMPLATE_BODY_FIELD_NUMBER: builtins.int
    TEMPLATE_S3_URI_FIELD_NUMBER: builtins.int
    CONFORMANCE_PACK_INPUT_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    conformance_pack_name: builtins.str
    delivery_s3_bucket: builtins.str
    delivery_s3_key_prefix: builtins.str
    template_body: builtins.str
    template_s3_uri: builtins.str
    @property
    def conformance_pack_input_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConformancePackConformancePackInputParameter]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        conformance_pack_name: builtins.str = ...,
        delivery_s3_bucket: builtins.str = ...,
        delivery_s3_key_prefix: builtins.str = ...,
        template_body: builtins.str = ...,
        template_s3_uri: builtins.str = ...,
        conformance_pack_input_parameters: collections.abc.Iterable[global___ConformancePackConformancePackInputParameter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conformance_pack_input_parameters", b"conformance_pack_input_parameters", "conformance_pack_name", b"conformance_pack_name", "delivery_s3_bucket", b"delivery_s3_bucket", "delivery_s3_key_prefix", b"delivery_s3_key_prefix", "resource_info", b"resource_info", "template_body", b"template_body", "template_s3_uri", b"template_s3_uri"]) -> None: ...

global___ConformancePack = ConformancePack

@typing_extensions.final
class DeliveryChannelConfigSnapshotDeliveryProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DELIVERY_FREQUENCY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    delivery_frequency: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        delivery_frequency: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_frequency", b"delivery_frequency", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryChannelConfigSnapshotDeliveryProperties = DeliveryChannelConfigSnapshotDeliveryProperties

@typing_extensions.final
class DeliveryChannel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONFIG_SNAPSHOT_DELIVERY_PROPERTIES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    S3_BUCKET_NAME_FIELD_NUMBER: builtins.int
    S3_KEY_PREFIX_FIELD_NUMBER: builtins.int
    SNS_TOPIC_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def config_snapshot_delivery_properties(self) -> global___DeliveryChannelConfigSnapshotDeliveryProperties: ...
    name: builtins.str
    s3_bucket_name: builtins.str
    s3_key_prefix: builtins.str
    sns_topic_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        config_snapshot_delivery_properties: global___DeliveryChannelConfigSnapshotDeliveryProperties | None = ...,
        name: builtins.str = ...,
        s3_bucket_name: builtins.str = ...,
        s3_key_prefix: builtins.str = ...,
        sns_topic_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config_snapshot_delivery_properties", b"config_snapshot_delivery_properties", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_snapshot_delivery_properties", b"config_snapshot_delivery_properties", "name", b"name", "resource_info", b"resource_info", "s3_bucket_name", b"s3_bucket_name", "s3_key_prefix", b"s3_key_prefix", "sns_topic_arn", b"sns_topic_arn"]) -> None: ...

global___DeliveryChannel = DeliveryChannel

@typing_extensions.final
class OrganizationConfigRuleOrganizationManagedRuleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAG_KEY_SCOPE_FIELD_NUMBER: builtins.int
    TAG_VALUE_SCOPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RESOURCE_ID_SCOPE_FIELD_NUMBER: builtins.int
    RULE_IDENTIFIER_FIELD_NUMBER: builtins.int
    RESOURCE_TYPES_SCOPE_FIELD_NUMBER: builtins.int
    MAXIMUM_EXECUTION_FREQUENCY_FIELD_NUMBER: builtins.int
    INPUT_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    tag_key_scope: builtins.str
    tag_value_scope: builtins.str
    description: builtins.str
    resource_id_scope: builtins.str
    rule_identifier: builtins.str
    @property
    def resource_types_scope(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    maximum_execution_frequency: builtins.str
    input_parameters: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tag_key_scope: builtins.str = ...,
        tag_value_scope: builtins.str = ...,
        description: builtins.str = ...,
        resource_id_scope: builtins.str = ...,
        rule_identifier: builtins.str = ...,
        resource_types_scope: collections.abc.Iterable[builtins.str] | None = ...,
        maximum_execution_frequency: builtins.str = ...,
        input_parameters: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "input_parameters", b"input_parameters", "maximum_execution_frequency", b"maximum_execution_frequency", "resource_id_scope", b"resource_id_scope", "resource_info", b"resource_info", "resource_types_scope", b"resource_types_scope", "rule_identifier", b"rule_identifier", "tag_key_scope", b"tag_key_scope", "tag_value_scope", b"tag_value_scope"]) -> None: ...

global___OrganizationConfigRuleOrganizationManagedRuleMetadata = OrganizationConfigRuleOrganizationManagedRuleMetadata

@typing_extensions.final
class OrganizationConfigRuleOrganizationCustomRuleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAG_KEY_SCOPE_FIELD_NUMBER: builtins.int
    TAG_VALUE_SCOPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RESOURCE_ID_SCOPE_FIELD_NUMBER: builtins.int
    LAMBDA_FUNCTION_ARN_FIELD_NUMBER: builtins.int
    ORGANIZATION_CONFIG_RULE_TRIGGER_TYPES_FIELD_NUMBER: builtins.int
    RESOURCE_TYPES_SCOPE_FIELD_NUMBER: builtins.int
    MAXIMUM_EXECUTION_FREQUENCY_FIELD_NUMBER: builtins.int
    INPUT_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    tag_key_scope: builtins.str
    tag_value_scope: builtins.str
    description: builtins.str
    resource_id_scope: builtins.str
    lambda_function_arn: builtins.str
    @property
    def organization_config_rule_trigger_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_types_scope(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    maximum_execution_frequency: builtins.str
    input_parameters: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tag_key_scope: builtins.str = ...,
        tag_value_scope: builtins.str = ...,
        description: builtins.str = ...,
        resource_id_scope: builtins.str = ...,
        lambda_function_arn: builtins.str = ...,
        organization_config_rule_trigger_types: collections.abc.Iterable[builtins.str] | None = ...,
        resource_types_scope: collections.abc.Iterable[builtins.str] | None = ...,
        maximum_execution_frequency: builtins.str = ...,
        input_parameters: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "input_parameters", b"input_parameters", "lambda_function_arn", b"lambda_function_arn", "maximum_execution_frequency", b"maximum_execution_frequency", "organization_config_rule_trigger_types", b"organization_config_rule_trigger_types", "resource_id_scope", b"resource_id_scope", "resource_info", b"resource_info", "resource_types_scope", b"resource_types_scope", "tag_key_scope", b"tag_key_scope", "tag_value_scope", b"tag_value_scope"]) -> None: ...

global___OrganizationConfigRuleOrganizationCustomRuleMetadata = OrganizationConfigRuleOrganizationCustomRuleMetadata

@typing_extensions.final
class OrganizationConfigRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ORGANIZATION_MANAGED_RULE_METADATA_FIELD_NUMBER: builtins.int
    ORGANIZATION_CONFIG_RULE_NAME_FIELD_NUMBER: builtins.int
    ORGANIZATION_CUSTOM_RULE_METADATA_FIELD_NUMBER: builtins.int
    EXCLUDED_ACCOUNTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def organization_managed_rule_metadata(self) -> global___OrganizationConfigRuleOrganizationManagedRuleMetadata: ...
    organization_config_rule_name: builtins.str
    @property
    def organization_custom_rule_metadata(self) -> global___OrganizationConfigRuleOrganizationCustomRuleMetadata: ...
    @property
    def excluded_accounts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        organization_managed_rule_metadata: global___OrganizationConfigRuleOrganizationManagedRuleMetadata | None = ...,
        organization_config_rule_name: builtins.str = ...,
        organization_custom_rule_metadata: global___OrganizationConfigRuleOrganizationCustomRuleMetadata | None = ...,
        excluded_accounts: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["organization_custom_rule_metadata", b"organization_custom_rule_metadata", "organization_managed_rule_metadata", b"organization_managed_rule_metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["excluded_accounts", b"excluded_accounts", "organization_config_rule_name", b"organization_config_rule_name", "organization_custom_rule_metadata", b"organization_custom_rule_metadata", "organization_managed_rule_metadata", b"organization_managed_rule_metadata", "resource_info", b"resource_info"]) -> None: ...

global___OrganizationConfigRule = OrganizationConfigRule

@typing_extensions.final
class OrganizationConformancePackConformancePackInputParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARAMETER_NAME_FIELD_NUMBER: builtins.int
    PARAMETER_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    parameter_name: builtins.str
    parameter_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        parameter_name: builtins.str = ...,
        parameter_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameter_name", b"parameter_name", "parameter_value", b"parameter_value", "resource_info", b"resource_info"]) -> None: ...

global___OrganizationConformancePackConformancePackInputParameter = OrganizationConformancePackConformancePackInputParameter

@typing_extensions.final
class OrganizationConformancePack(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ORGANIZATION_CONFORMANCE_PACK_NAME_FIELD_NUMBER: builtins.int
    TEMPLATE_S3_URI_FIELD_NUMBER: builtins.int
    TEMPLATE_BODY_FIELD_NUMBER: builtins.int
    DELIVERY_S3_BUCKET_FIELD_NUMBER: builtins.int
    DELIVERY_S3_KEY_PREFIX_FIELD_NUMBER: builtins.int
    CONFORMANCE_PACK_INPUT_PARAMETERS_FIELD_NUMBER: builtins.int
    EXCLUDED_ACCOUNTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    organization_conformance_pack_name: builtins.str
    template_s3_uri: builtins.str
    template_body: builtins.str
    delivery_s3_bucket: builtins.str
    delivery_s3_key_prefix: builtins.str
    @property
    def conformance_pack_input_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OrganizationConformancePackConformancePackInputParameter]: ...
    @property
    def excluded_accounts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        organization_conformance_pack_name: builtins.str = ...,
        template_s3_uri: builtins.str = ...,
        template_body: builtins.str = ...,
        delivery_s3_bucket: builtins.str = ...,
        delivery_s3_key_prefix: builtins.str = ...,
        conformance_pack_input_parameters: collections.abc.Iterable[global___OrganizationConformancePackConformancePackInputParameter] | None = ...,
        excluded_accounts: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conformance_pack_input_parameters", b"conformance_pack_input_parameters", "delivery_s3_bucket", b"delivery_s3_bucket", "delivery_s3_key_prefix", b"delivery_s3_key_prefix", "excluded_accounts", b"excluded_accounts", "organization_conformance_pack_name", b"organization_conformance_pack_name", "resource_info", b"resource_info", "template_body", b"template_body", "template_s3_uri", b"template_s3_uri"]) -> None: ...

global___OrganizationConformancePack = OrganizationConformancePack

@typing_extensions.final
class RemediationConfigurationSsmControls(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ERROR_PERCENTAGE_FIELD_NUMBER: builtins.int
    CONCURRENT_EXECUTION_RATE_PERCENTAGE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    error_percentage: builtins.int
    concurrent_execution_rate_percentage: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        error_percentage: builtins.int = ...,
        concurrent_execution_rate_percentage: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["concurrent_execution_rate_percentage", b"concurrent_execution_rate_percentage", "error_percentage", b"error_percentage", "resource_info", b"resource_info"]) -> None: ...

global___RemediationConfigurationSsmControls = RemediationConfigurationSsmControls

@typing_extensions.final
class RemediationConfigurationExecutionControls(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SSM_CONTROLS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def ssm_controls(self) -> global___RemediationConfigurationSsmControls: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ssm_controls: global___RemediationConfigurationSsmControls | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "ssm_controls", b"ssm_controls"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "ssm_controls", b"ssm_controls"]) -> None: ...

global___RemediationConfigurationExecutionControls = RemediationConfigurationExecutionControls

@typing_extensions.final
class RemediationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TARGET_VERSION_FIELD_NUMBER: builtins.int
    EXECUTION_CONTROLS_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    TARGET_TYPE_FIELD_NUMBER: builtins.int
    CONFIG_RULE_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    RETRY_ATTEMPT_SECONDS_FIELD_NUMBER: builtins.int
    MAXIMUM_AUTOMATIC_ATTEMPTS_FIELD_NUMBER: builtins.int
    TARGET_ID_FIELD_NUMBER: builtins.int
    AUTOMATIC_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    target_version: builtins.str
    @property
    def execution_controls(self) -> global___RemediationConfigurationExecutionControls: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    target_type: builtins.str
    config_rule_name: builtins.str
    resource_type: builtins.str
    retry_attempt_seconds: builtins.int
    maximum_automatic_attempts: builtins.int
    target_id: builtins.str
    automatic: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        target_version: builtins.str = ...,
        execution_controls: global___RemediationConfigurationExecutionControls | None = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        target_type: builtins.str = ...,
        config_rule_name: builtins.str = ...,
        resource_type: builtins.str = ...,
        retry_attempt_seconds: builtins.int = ...,
        maximum_automatic_attempts: builtins.int = ...,
        target_id: builtins.str = ...,
        automatic: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["execution_controls", b"execution_controls", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["automatic", b"automatic", "config_rule_name", b"config_rule_name", "execution_controls", b"execution_controls", "maximum_automatic_attempts", b"maximum_automatic_attempts", "parameters", b"parameters", "resource_info", b"resource_info", "resource_type", b"resource_type", "retry_attempt_seconds", b"retry_attempt_seconds", "target_id", b"target_id", "target_type", b"target_type", "target_version", b"target_version"]) -> None: ...

global___RemediationConfiguration = RemediationConfiguration

@typing_extensions.final
class RemediationConfigurationResourceValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___RemediationConfigurationResourceValue = RemediationConfigurationResourceValue

@typing_extensions.final
class RemediationConfigurationStaticValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___RemediationConfigurationStaticValue = RemediationConfigurationStaticValue

@typing_extensions.final
class RemediationConfigurationRemediationParameterValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_VALUE_FIELD_NUMBER: builtins.int
    STATIC_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def resource_value(self) -> global___RemediationConfigurationResourceValue: ...
    @property
    def static_value(self) -> global___RemediationConfigurationStaticValue: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_value: global___RemediationConfigurationResourceValue | None = ...,
        static_value: global___RemediationConfigurationStaticValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "resource_value", b"resource_value", "static_value", b"static_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "resource_value", b"resource_value", "static_value", b"static_value"]) -> None: ...

global___RemediationConfigurationRemediationParameterValue = RemediationConfigurationRemediationParameterValue



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_privatednszones.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3azure/azure_microsoft_network_privatednszones.proto\x12\x33oak9.tython.azure.microsoft_network_privatednszones\x1a\x13shared/shared.proto\"\x8f\x02\n!Microsoft_Network_privateDnsZones\x12_\n\x11private_dns_zones\x18\x01 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZones\x12\x88\x01\n\'private_dns_zones_virtual_network_links\x18\x02 \x03(\x0b\x32W.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesVirtualNetworkLinks\"\xb6\x07\n\x12PrivateDnsZonesTXT\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12g\n\x08metadata\x18\x04 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesTXT.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x07\n\x12PrivateDnsZonesSRV\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12g\n\x08metadata\x18\x04 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesSRV.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x07\n\x12PrivateDnsZonesSOA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12g\n\x08metadata\x18\x04 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesSOA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x07\n\x12PrivateDnsZonesPTR\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12g\n\x08metadata\x18\x04 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesPTR.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb4\x07\n\x11PrivateDnsZonesMX\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\x66\n\x08metadata\x18\x04 \x03(\x0b\x32T.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesMX.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xba\x07\n\x14PrivateDnsZonesCNAME\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12i\n\x08metadata\x18\x04 \x03(\x0b\x32W.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesCNAME.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb8\x07\n\x13PrivateDnsZonesAAAA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12h\n\x08metadata\x18\x04 \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesAAAA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2\x07\n\x10PrivateDnsZonesA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\x65\n\x08metadata\x18\x04 \x03(\x0b\x32S.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12O\n\ta_records\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_network_privatednszones.ARecord\x12U\n\x0c\x61\x61\x61\x61_records\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_privatednszones.AaaaRecord\x12V\n\x0c\x63name_record\x18\x08 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_privatednszones.CnameRecord\x12Q\n\nmx_records\x18\t \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_privatednszones.MxRecord\x12S\n\x0bptr_records\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.PtrRecord\x12R\n\nsoa_record\x18\x0b \x01(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SoaRecord\x12S\n\x0bsrv_records\x18\x0c \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.SrvRecord\x12S\n\x0btxt_records\x18\r \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_privatednszones.TxtRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1a\n\tTxtRecord\x12\r\n\x05value\x18\x01 \x03(\t\"K\n\tSrvRecord\x12\x10\n\x08priority\x18\x01 \x01(\x05\x12\x0e\n\x06weight\x18\x02 \x01(\x05\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x0e\n\x06target\x18\x04 \x01(\t\"\x93\x01\n\tSoaRecord\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x15\n\rserial_number\x18\x03 \x01(\x05\x12\x14\n\x0crefresh_time\x18\x04 \x01(\x05\x12\x12\n\nretry_time\x18\x05 \x01(\x05\x12\x13\n\x0b\x65xpire_time\x18\x06 \x01(\x05\x12\x13\n\x0bminimum_ttl\x18\x07 \x01(\x05\"\x1d\n\tPtrRecord\x12\x10\n\x08ptrdname\x18\x01 \x01(\t\"0\n\x08MxRecord\x12\x12\n\npreference\x18\x01 \x01(\x05\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\"\x1c\n\x0b\x43nameRecord\x12\r\n\x05\x63name\x18\x01 \x01(\t\"\"\n\nAaaaRecord\x12\x14\n\x0cipv6_address\x18\x01 \x01(\t\"\x1f\n\x07\x41Record\x12\x14\n\x0cipv4_address\x18\x01 \x01(\t\"\xce\x02\n\"PrivateDnsZonesVirtualNetworkLinks\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12o\n\x04tags\x18\x03 \x03(\x0b\x32\x61.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesVirtualNetworkLinks.TagsEntry\x12\x0c\n\x04\x65tag\x18\x04 \x01(\t\x12\x17\n\x0fvirtual_network\x18\x05 \x01(\t\x12\x1c\n\x14registration_enabled\x18\x06 \x01(\x08\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcb\x08\n\x0fPrivateDnsZones\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\\\n\x04tags\x18\x04 \x03(\x0b\x32N.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZones.TagsEntry\x12\x0c\n\x04\x65tag\x18\x05 \x01(\t\x12\x63\n\x14private_dns_zones__a\x18\x06 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesA\x12i\n\x17private_dns_zones__aaaa\x18\x07 \x03(\x0b\x32H.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesAAAA\x12k\n\x18private_dns_zones__cname\x18\x08 \x03(\x0b\x32I.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesCNAME\x12\x65\n\x15private_dns_zones__mx\x18\t \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesMX\x12g\n\x16private_dns_zones__ptr\x18\n \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesPTR\x12g\n\x16private_dns_zones__soa\x18\x0b \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesSOA\x12g\n\x16private_dns_zones__srv\x18\x0c \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesSRV\x12g\n\x16private_dns_zones__txt\x18\r \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_privatednszones.PrivateDnsZonesTXT\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_privatednszones_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRIVATEDNSZONESTXT_METADATAENTRY._options = None
  _PRIVATEDNSZONESTXT_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESSRV_METADATAENTRY._options = None
  _PRIVATEDNSZONESSRV_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESSOA_METADATAENTRY._options = None
  _PRIVATEDNSZONESSOA_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESPTR_METADATAENTRY._options = None
  _PRIVATEDNSZONESPTR_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESMX_METADATAENTRY._options = None
  _PRIVATEDNSZONESMX_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESCNAME_METADATAENTRY._options = None
  _PRIVATEDNSZONESCNAME_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESAAAA_METADATAENTRY._options = None
  _PRIVATEDNSZONESAAAA_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESA_METADATAENTRY._options = None
  _PRIVATEDNSZONESA_METADATAENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONESVIRTUALNETWORKLINKS_TAGSENTRY._options = None
  _PRIVATEDNSZONESVIRTUALNETWORKLINKS_TAGSENTRY._serialized_options = b'8\001'
  _PRIVATEDNSZONES_TAGSENTRY._options = None
  _PRIVATEDNSZONES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_PRIVATEDNSZONES._serialized_start=130
  _MICROSOFT_NETWORK_PRIVATEDNSZONES._serialized_end=401
  _PRIVATEDNSZONESTXT._serialized_start=404
  _PRIVATEDNSZONESTXT._serialized_end=1354
  _PRIVATEDNSZONESTXT_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESTXT_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESSRV._serialized_start=1357
  _PRIVATEDNSZONESSRV._serialized_end=2307
  _PRIVATEDNSZONESSRV_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESSRV_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESSOA._serialized_start=2310
  _PRIVATEDNSZONESSOA._serialized_end=3260
  _PRIVATEDNSZONESSOA_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESSOA_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESPTR._serialized_start=3263
  _PRIVATEDNSZONESPTR._serialized_end=4213
  _PRIVATEDNSZONESPTR_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESPTR_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESMX._serialized_start=4216
  _PRIVATEDNSZONESMX._serialized_end=5164
  _PRIVATEDNSZONESMX_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESMX_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESCNAME._serialized_start=5167
  _PRIVATEDNSZONESCNAME._serialized_end=6121
  _PRIVATEDNSZONESCNAME_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESCNAME_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESAAAA._serialized_start=6124
  _PRIVATEDNSZONESAAAA._serialized_end=7076
  _PRIVATEDNSZONESAAAA_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESAAAA_METADATAENTRY._serialized_end=1354
  _PRIVATEDNSZONESA._serialized_start=7079
  _PRIVATEDNSZONESA._serialized_end=8025
  _PRIVATEDNSZONESA_METADATAENTRY._serialized_start=1307
  _PRIVATEDNSZONESA_METADATAENTRY._serialized_end=1354
  _TXTRECORD._serialized_start=8027
  _TXTRECORD._serialized_end=8053
  _SRVRECORD._serialized_start=8055
  _SRVRECORD._serialized_end=8130
  _SOARECORD._serialized_start=8133
  _SOARECORD._serialized_end=8280
  _PTRRECORD._serialized_start=8282
  _PTRRECORD._serialized_end=8311
  _MXRECORD._serialized_start=8313
  _MXRECORD._serialized_end=8361
  _CNAMERECORD._serialized_start=8363
  _CNAMERECORD._serialized_end=8391
  _AAAARECORD._serialized_start=8393
  _AAAARECORD._serialized_end=8427
  _ARECORD._serialized_start=8429
  _ARECORD._serialized_end=8460
  _PRIVATEDNSZONESVIRTUALNETWORKLINKS._serialized_start=8463
  _PRIVATEDNSZONESVIRTUALNETWORKLINKS._serialized_end=8797
  _PRIVATEDNSZONESVIRTUALNETWORKLINKS_TAGSENTRY._serialized_start=8754
  _PRIVATEDNSZONESVIRTUALNETWORKLINKS_TAGSENTRY._serialized_end=8797
  _PRIVATEDNSZONES._serialized_start=8800
  _PRIVATEDNSZONES._serialized_end=9899
  _PRIVATEDNSZONES_TAGSENTRY._serialized_start=8754
  _PRIVATEDNSZONES_TAGSENTRY._serialized_end=8797
# @@protoc_insertion_point(module_scope)
